<?php
/**
 * Contact options
 *
 * @package Theme Palace
 * @subpackage Korpo
 * @since Korpo 1.0.0
 */

// Add Contact section
$wp_customize->add_section( 'korpo_contact_section', array(
	'title'             => esc_html__( 'Contact Details','korpo' ),
	'description'       => esc_html__( 'Contact Section options.', 'korpo' ),
	'panel'             => 'korpo_front_page_panel',
) );

// Contact content enable control and setting
$wp_customize->add_setting( 'korpo_theme_options[contact_section_enable]', array(
	'default'			=> 	$options['contact_section_enable'],
	'sanitize_callback' => 'korpo_sanitize_switch_control',
) );

$wp_customize->add_control( new Korpo_Switch_Control( $wp_customize, 'korpo_theme_options[contact_section_enable]', array(
	'label'             => esc_html__( 'Contact Section Enable', 'korpo' ),
	'section'           => 'korpo_contact_section',
	'on_off_label' 		=> korpo_switch_options(),
) ) );

// Contact us title setting and control
$wp_customize->add_setting( 'korpo_theme_options[contact_title]', array(
	'sanitize_callback' => 'sanitize_text_field',
	'default'          	=> $options['contact_title'],
	'transport'			=> 'postMessage',
) );

$wp_customize->add_control( 'korpo_theme_options[contact_title]', array(
	'label'           	=> esc_html__( 'Title', 'korpo' ),
	'section'        	=> 'korpo_contact_section',
	'active_callback' 	=> 'korpo_is_contact_section_enable',
	'type'				=> 'text',
) );

// Abort if selective refresh is not available.
if ( isset( $wp_customize->selective_refresh ) ) {
    $wp_customize->selective_refresh->add_partial( 'korpo_theme_options[contact_title]', array(
		'selector'            => '#contact-us .wrapper h2.section-title',
		'settings'            => 'korpo_theme_options[contact_title]',
		'container_inclusive' => false,
		'fallback_refresh'    => true,
		'render_callback'     => 'korpo_contact_title_partial',
    ) );
}

// Contact us address title setting and control
$wp_customize->add_setting( 'korpo_theme_options[contact_sub_title]', array(
	'sanitize_callback' => 'sanitize_text_field',
	'default'          	=> $options['contact_sub_title'],
	'transport'			=> 'postMessage',
) );

$wp_customize->add_control( 'korpo_theme_options[contact_sub_title]', array(
	'label'           	=> esc_html__( 'Sub Title', 'korpo' ),
	'section'        	=> 'korpo_contact_section',
	'active_callback' 	=> 'korpo_is_contact_section_enable',
	'type'				=> 'text',
) );

// Abort if selective refresh is not available.
if ( isset( $wp_customize->selective_refresh ) ) {
    $wp_customize->selective_refresh->add_partial( 'korpo_theme_options[contact_sub_title]', array(
		'selector'            => '#contact-us .wrapper .section-content .contact-address ul li label.address-title',
		'settings'            => 'korpo_theme_options[contact_sub_title]',
		'container_inclusive' => false,
		'fallback_refresh'    => true,
		'render_callback'     => 'korpo_contact_sub_title_partial',
    ) );
}

// map setting and control
$wp_customize->add_setting( 'korpo_theme_options[contact_map]', array(
	'sanitize_callback' => 'sanitize_text_field',
) );

$wp_customize->add_control( 'korpo_theme_options[contact_map]', array(
	'label'           	=> esc_html__( 'Map Shortcode', 'korpo' ),
	'description'       => sprintf( '%1$s <a href="' . esc_url( admin_url( 'themes.php?page=tgmpa-install-plugins' ) ) .'" target="_blank"> %2$s </a> %3$s', esc_html__( 'Input shortcode from WP Google Maps Plugin', 'korpo' ), esc_html__( 'Click Here', 'korpo' ), esc_html__( 'to download plugin.', 'korpo' ) ),
	'section'        	=> 'korpo_contact_section',
	'active_callback' 	=> 'korpo_is_contact_section_enable',
	'type'				=> 'text',
) );

// Contact form setting and control
$wp_customize->add_setting( 'korpo_theme_options[contact_form]', array(
	'sanitize_callback' => 'sanitize_text_field',
) );

$wp_customize->add_control( 'korpo_theme_options[contact_form]', array(
	'label'           	=> esc_html__( 'Contact Form Shortcode', 'korpo' ),
	'description'       => sprintf( '%1$s <a href="' . esc_url( admin_url( 'themes.php?page=tgmpa-install-plugins' ) ) .'" target="_blank"> %2$s </a> %3$s', esc_html__( 'Input shortcode from Contact Form 7 Plugin', 'korpo' ), esc_html__( 'Click Here', 'korpo' ), esc_html__( 'to download plugin.', 'korpo' ) ),
	'section'        	=> 'korpo_contact_section',
	'active_callback' 	=> 'korpo_is_contact_section_enable',
	'type'				=> 'text',
) );
