<?php
/**
 * Service section
 *
 * This is the template for the content of service section
 *
 * @package Theme Palace
 * @subpackage Korpo
 * @since Korpo 1.0.0
 */
if ( ! function_exists( 'korpo_add_service_section' ) ) :
    /**
    * Add service section
    *
    *@since Korpo 1.0.0
    */
    function korpo_add_service_section() {
    	$options = korpo_get_theme_options();
        // Check if service is enabled on frontpage
        $service_enable = apply_filters( 'korpo_section_status', true, 'service_section_enable' );

        if ( true !== $service_enable ) {
            return false;
        }
        // Get service section details
        $section_details = array();
        $section_details = apply_filters( 'korpo_filter_service_section_details', $section_details );

        if ( empty( $section_details ) ) {
            return;
        }

        // Render service section now.
        korpo_render_service_section( $section_details );
    }
endif;

if ( ! function_exists( 'korpo_get_service_section_details' ) ) :
    /**
    * service section details.
    *
    * @since Korpo 1.0.0
    * @param array $input service section details.
    */
    function korpo_get_service_section_details( $input ) {
        $options = korpo_get_theme_options();

        // Content type.
        $content = array();
        $page_ids = array();

        for ( $i = 1; $i <=  3; $i++ ) {
            if ( ! empty( $options['service_content_page_' . $i] ) )
                $page_ids[] = $options['service_content_page_' . $i];
        }
        
        $args = array(
            'post_type'         => 'page',
            'post__in'          => ( array ) $page_ids,
            'posts_per_page'    => 3,
            'orderby'           => 'post__in',
            );                    


            // Run The Loop.
            $query = new WP_Query( $args );
            if ( $query->have_posts() ) : 
                while ( $query->have_posts() ) : $query->the_post();
                    $page_post['title']     = get_the_title();
                    $page_post['excerpt']   = get_the_content();

                    // Push to the main array.
                    array_push( $content, $page_post );
                endwhile;
            endif;
            wp_reset_postdata();

            
        if ( ! empty( $content ) ) {
            $input = $content;
        }
        return $input;
    }
endif;
// service section content details.
add_filter( 'korpo_filter_service_section_details', 'korpo_get_service_section_details' );


if ( ! function_exists( 'korpo_render_service_section' ) ) :
  /**
   * Start service section
   *
   * @return string service content
   * @since Korpo 1.0.0
   *
   */
   function korpo_render_service_section( $content_details = array() ) {
        $options = korpo_get_theme_options();
        $title = ! empty( $options['service_title'] ) ? $options['service_title'] : '';
        $sub_title = ! empty( $options['service_sub_title'] ) ? $options['service_sub_title'] : '';
        $background = ! empty( $options['service_image'] ) ? $options['service_image'] : '';

        if ( empty( $content_details ) ) {
            return;
        } ?>
        <section id="our-services">
            <div class="services-section-wrapper <?php echo ! empty( $background ) ? 'has' : 'no'; ?>-featured-image">
                <div class="featured-image" 
                <?php if ( ! empty( $background ) ) : ?>
                    style="background-image: url('<?php echo esc_url( $background ); ?>');"
                <?php endif; ?>
                >
                    <div class="overlay"></div>
                </div><!-- .featured-image -->

                <div class="entry-container">
                    <?php if ( ! empty( $title ) || ! empty( $sub_title ) ) : ?>
                        <div class="section-header">
                            <?php if ( ! empty( $title ) ) : ?>
                                <span class="section-subtitle"><?php echo esc_html( $title ); ?></span>
                            <?php endif; 

                            if ( ! empty( $sub_title ) ) : ?>
                                <h2 class="section-title"><?php echo esc_html( $sub_title ); ?></h2>
                            <?php endif; ?>
                        </div><!-- .section-header -->
                    <?php endif; ?>

                    <div class="section-content">
                        <div class="faq-group">
                            <?php foreach ( $content_details as $content ) : ?>
                                <div class="each-faq">
                                    <a class="faq-trigger" href="#">
                                        <h4><?php echo esc_html( $content['title'] ); ?></h4>
                                        <button class="icon-trigger">
                                            <?php  
                                            echo korpo_get_svg( array( 'icon' => 'add' ) );
                                            echo korpo_get_svg( array( 'icon' => 'close' ) );
                                            ?>
                                        </button>
                                    </a><!-- .faq-trigger -->

                                    <div class="faq-content">
                                        <p><?php echo esc_html( $content['excerpt'] ); ?></p>
                                    </div> <!-- .faq-content -->
                                </div><!-- .each-faq -->
                            <?php endforeach; ?>
                        </div><!-- .faq-group -->
                    </div><!-- .section-content -->
                </div><!-- .entry-container -->
            </div>
        </section><!-- #our-services -->
    <?php }
endif;